package PDL::Fit;

use strict;
use warnings;

our $VERSION = '2.097';

=head1 NAME

PDL::Fit - various fitting implementations for PDL

=head1 DESCRIPTION

This distribution contains the following packages:

=over

=item L<PDL::Fit::Gaussian>

=item L<PDL::Fit::LM>

=item L<PDL::Fit::Linfit>

=item L<PDL::Fit::Polynomial>

=back

=cut

1;
